Allow class

Inheritance

Constructors

Allow({required String source, required String target, String? description})

Properties

description String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
target String
finalinherited
type String?
finalinherited

Methods

isAllowed(String sourcePackage, String source, String target) bool?
override
matches(String sourcePackage, String source, String target) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited